FlutterHttpRequestStream class

Constructors

FlutterHttpRequestStream()

Properties

hashCode → int
The hash code for this object.
no setterinherited
listener ↔ HttpRequestCallback?
getter/setter pair
req ↔ FlutterHttpRequest
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

listen(HttpRequestCallback onData, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited