Transport class abstract

Inheritance
Implementers

Constructors

Transport(Map opts)

Properties

agent bool?
getter/setter pair
enablesXDR bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostname String
getter/setter pair
name String?
getter/setter pair
path ↔ dynamic
getter/setter pair
port int?
getter/setter pair
query Map?
getter/setter pair
readyState String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secure bool
getter/setter pair
socket Socket?
getter/setter pair
supportsBinary bool?
getter/setter pair
timestampParam String?
getter/setter pair
timestampRequests bool?
getter/setter pair
writable bool?
getter/setter pair

Methods

clearListeners() → void
This function unbinds all the handlers for all the events.
inherited
close() → void
Closes the transport.
doClose() → void
doOpen() → void
emit(String event, [dynamic data]) → void
This function triggers all the handlers currently listening to event and passes them data.
inherited
hasListeners(String event) bool
Returns whether the event has registered.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off(String event, [EventHandler? handler]) → void
This function attempts to unbind the handler from the event
inherited
on(String event, EventHandler handler) → void
This function binds the handler as a listener to the event
inherited
once(String event, EventHandler handler) → void
This function binds the handler as a listener to the first occurrence of the event. When handler is called once, it is removed.
inherited
onClose() → void
Called upon close.
onData(dynamic data) → void
Called with data.
onError(dynamic msg, [dynamic desc]) → void
Emits an error.
onOpen() → void
Called upon open
onPacket(dynamic packet) → void
Called with a decoded packet.
open() → void
Opens the transport.
outOfBand(dynamic data) → void
Called with out of band data.
send(List packets) → void
Sends multiple packets.
toString() String
A string representation of this object.
inherited
write(List data) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited