Request class
Request constructor
@param {Object} options @api public
- Inheritance
-
- Object
- EventEmitter
- Request
Properties
- agent ↔ bool
-
getter/setter pair
- asynch ↔ bool
-
getter/setter pair
- data ↔ dynamic
-
getter/setter pair
- enablesXDR ↔ bool
-
getter/setter pair
-
extraHeaders
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBinary ↔ bool
-
getter/setter pair
- method ↔ String
-
getter/setter pair
- readyStateChange ↔ StreamSubscription?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsBinary ↔ bool
-
getter/setter pair
- uri ↔ String
-
getter/setter pair
- xd ↔ bool
-
getter/setter pair
- xhr ↔ HttpRequest?
-
getter/setter pair
- xs ↔ bool
-
getter/setter pair
Methods
-
abort(
) → void - Aborts the request.
-
cleanup(
[dynamic fromError]) → void - Cleans up house.
-
clearListeners(
) → void -
This function unbinds all the handlers for all the events.
inherited
-
create(
) → void - Creates the XHR object and sends the request.
-
emit(
String event, [dynamic data]) → void -
This function triggers all the handlers currently listening
to
eventand passes themdata.inherited -
hasListeners(
String event) → bool -
Returns whether the event has registered.
inherited
-
hasXDR(
) → bool - Check if it has XDomainRequest.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
off(
String event, [EventHandler? handler]) → void -
This function attempts to unbind the
handlerfrom theeventinherited -
on(
String event, EventHandler handler) → void -
This function binds the
handleras a listener to theeventinherited -
once(
String event, EventHandler handler) → void -
This function binds the
handleras a listener to the first occurrence of theevent. Whenhandleris called once, it is removed.inherited -
onData(
dynamic data) → void - Called if we have data.
-
onError(
dynamic err) → void - Called upon error.
-
onLoad(
) → void - Called upon load.
-
onSuccess(
) → void - Called upon successful response.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited